@@ -1,22 +1,9 @@
 /*  This file was part of the KDE libraries
 
-    Copyright 2002 Carsten Pfeiffer <pfeiffer@kde.org>
-    Copyright 2007-2008 Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2002 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 Robert Knight <robertknight@gmail.com>
 
-    library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation, version 2
-    or ( at your option ), any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Born as kdelibs/kio/kfile/kfilebookmarkhandler.cpp
@@ -73,12 +60,12 @@ BookmarkHandler::~BookmarkHandler() = default;
 
 void BookmarkHandler::openBookmark(const KBookmark &bm, Qt::MouseButtons, Qt::KeyboardModifiers)
 {
-    emit openUrl(bm.url());
+    Q_EMIT openUrl(bm.url());
 }
 
 void BookmarkHandler::openFolderinTabs(const KBookmarkGroup &group)
 {
-    emit openUrls(group.groupUrlList());
+    Q_EMIT openUrls(group.groupUrlList());
 }
 
 bool BookmarkHandler::enableOption(BookmarkOption option) const
