@@ -28,68 +28,70 @@ HistoryScrollFile::HistoryScrollFile() :
 
 HistoryScrollFile::~HistoryScrollFile() = default;
 
-int HistoryScrollFile::getLines()
+int HistoryScrollFile::getLines() const
 {
     return _index.len() / sizeof(qint64);
 }
 
-int HistoryScrollFile::getMaxLines()
+int HistoryScrollFile::getMaxLines() const
 {
     return getLines();
 }
 
-int HistoryScrollFile::getLineLen(int lineno)
+int HistoryScrollFile::getLineLen(const int lineno) const
 {
     return (startOfLine(lineno + 1) - startOfLine(lineno)) / sizeof(Character);
 }
 
-bool HistoryScrollFile::isWrappedLine(int lineno)
+bool HistoryScrollFile::isWrappedLine(const int lineno) const
 {
-    if (lineno >= 0 && lineno <= getLines()) {
-        unsigned char flag = 0;
-        _lineflags.get(reinterpret_cast<char *>(&flag), sizeof(unsigned char),
-                       (lineno)*sizeof(unsigned char));
-        return flag != 0u;
-    }
-    return false;
+    return (getLineProperty(lineno) & LINE_WRAPPED) > 0;
 }
 
-qint64 HistoryScrollFile::startOfLine(int lineno)
+LineProperty HistoryScrollFile::getLineProperty(const int lineno) const
 {
-    if (lineno <= 0) {
+    if (lineno >= 0 && lineno <= getLines()) {
+        LineProperty flag = 0;
+        _lineflags.get(reinterpret_cast<char *>(&flag), sizeof(unsigned char),
+                       (lineno) * sizeof(unsigned char));
+        return flag;
+    }
+    return 0;
+}
+
+qint64 HistoryScrollFile::startOfLine(const int lineno) const
+{
+    Q_ASSERT(lineno >= 0 && lineno <= getLines());
+
+    if (lineno == 0) {
         return 0;
     }
-    if (lineno <= getLines()) {
+    if (lineno < getLines()) {
         qint64 res = 0;
-        _index.get(reinterpret_cast<char*>(&res), sizeof(qint64), (lineno - 1)*sizeof(qint64));
+        _index.get(reinterpret_cast<char *>(&res), sizeof(qint64), (lineno - 1) * sizeof(qint64));
         return res;
     }
     return _cells.len();
 }
 
-void HistoryScrollFile::getCells(int lineno, int colno, int count, Character res[])
+void HistoryScrollFile::getCells(const int lineno, const int colno, const int count, Character res[]) const
 {
-    _cells.get(reinterpret_cast<char*>(res), count * sizeof(Character), startOfLine(lineno) + colno * sizeof(Character));
+    _cells.get(reinterpret_cast<char *>(res), count * sizeof(Character), startOfLine(lineno) + colno * sizeof(Character));
 }
 
-void HistoryScrollFile::addCells(const Character text[], int count)
+void HistoryScrollFile::addCells(const Character text[], const int count)
 {
-    _cells.add(reinterpret_cast<const char*>(text), count * sizeof(Character));
+    _cells.add(reinterpret_cast<const char *>(text), count * sizeof(Character));
 }
 
-void HistoryScrollFile::addLine(bool previousWrapped)
+void HistoryScrollFile::addLine(LineProperty lineProperty)
 {
     qint64 locn = _cells.len();
     _index.add(reinterpret_cast<char *>(&locn), sizeof(qint64));
-    unsigned char flags = previousWrapped ? 0x01 : 0x00;
-    _lineflags.add(reinterpret_cast<char *>(&flags), sizeof(char));
+    _lineflags.add(reinterpret_cast<char *>(&lineProperty), sizeof(char));
 }
 
-void HistoryScrollFile::insertCells(int, const Character[], int)
-{
-}
-
-void HistoryScrollFile::removeCells(int)
+void HistoryScrollFile::removeCells()
 {
     qint64 res = (getLines() - 2) * sizeof(qint64);
     if (getLines() < 2) {
@@ -103,35 +105,15 @@ void HistoryScrollFile::removeCells(int)
     _lineflags.removeLast(res * sizeof(unsigned char));
 }
 
-void HistoryScrollFile::insertCellsVector(int, const QVector<Character> &)
+int HistoryScrollFile::reflowLines(const int columns)
 {
-}
-
-void HistoryScrollFile::setCellsAt(int, const Character text[], int count)
-{
-    qint64 res = (getLines() - 2) * sizeof(qint64);
-    if (getLines() < 2) {
-        _cells.removeLast(0);
-    } else {
-        _index.get(reinterpret_cast<char *>(&res), sizeof(qint64), res);
-        _cells.removeLast(res);
-    }
-    _cells.add(reinterpret_cast<const char *>(text), count * sizeof(Character));
-}
-
-void HistoryScrollFile::setCellsVectorAt(int, const QVector<Character> &)
-{
-}
-
-int HistoryScrollFile::reflowLines(int columns)
-{
-    HistoryFile *reflowFile = new HistoryFile;
+    auto reflowFile = std::make_unique<HistoryFile>();
     reflowData newLine;
 
-    auto reflowLineLen = [] (qint64 start, qint64 end) {
+    auto reflowLineLen = [](qint64 start, qint64 end) {
         return (int)((end - start) / sizeof(Character));
     };
-    auto setNewLine = [] (reflowData &change, qint64 index, bool lineflag) {
+    auto setNewLine = [](reflowData &change, qint64 index, LineProperty lineflag) {
         change.index = index;
         change.lineFlag = lineflag;
     };
@@ -144,20 +126,21 @@ int HistoryScrollFile::reflowLines(int columns)
     while (currentPos < getLines()) {
         qint64 startLine = startOfLine(currentPos);
         qint64 endLine = startOfLine(currentPos + 1);
+        LineProperty lineProperty = getLineProperty(currentPos);
 
         // Join the lines if they are wrapped
-        while (isWrappedLine(currentPos)) {
+        while (currentPos < getLines() - 1 && isWrappedLine(currentPos)) {
             currentPos++;
             endLine = startOfLine(currentPos + 1);
         }
 
         // Now reflow the lines
-        while (reflowLineLen(startLine, endLine) > columns) {
+        while (reflowLineLen(startLine, endLine) > columns && !(lineProperty & (LINE_DOUBLEHEIGHT_BOTTOM | LINE_DOUBLEHEIGHT_TOP))) {
             startLine += (qint64)columns * sizeof(Character);
-            setNewLine(newLine, startLine, true);
+            setNewLine(newLine, startLine, lineProperty | LINE_WRAPPED);
             reflowFile->add(reinterpret_cast<const char *>(&newLine), sizeof(reflowData));
         }
-        setNewLine(newLine, endLine, false);
+        setNewLine(newLine, endLine, lineProperty & ~LINE_WRAPPED);
         reflowFile->add(reinterpret_cast<const char *>(&newLine), sizeof(reflowData));
         currentPos++;
     }
@@ -178,25 +161,10 @@ int HistoryScrollFile::reflowLines(int columns)
     while (currentPos < totalLines) {
         reflowFile->get(reinterpret_cast<char *>(&newLine), sizeof(reflowData), currentPos * sizeof(reflowData));
 
-        unsigned char flags = newLine.lineFlag ? 0x01 : 0x00;
-        _lineflags.add(reinterpret_cast<char *>(&flags), sizeof(char));
+        _lineflags.add(reinterpret_cast<char *>(&newLine.lineFlag), sizeof(char));
         _index.add(reinterpret_cast<char *>(&newLine.index), sizeof(qint64));
         currentPos++;
     }
 
-    delete reflowFile;
     return 0;
 }
-
-void HistoryScrollFile::setLineAt(int, bool previousWrapped)
-{
-    qint64 locn = qMax(0, getLines() - 1);
-    _index.removeLast(locn * sizeof(qint64));
-    _lineflags.removeLast(locn * sizeof(unsigned char));
-
-    locn = _cells.len();
-    _index.add(reinterpret_cast<char *>(&locn), sizeof(qint64));
-
-    unsigned char flags = previousWrapped ? 0x01 : 0x00;
-    _lineflags.add(reinterpret_cast<char *>(&flags), sizeof(char));
-}
