@@ -13,6 +13,8 @@
 #include <QPointer>
 #include <QWidget>
 
+#include <memory>
+
 // Konsole
 #include "../characters/Character.h"
 #include "konsoleprivate_export.h"
@@ -22,6 +24,8 @@
 #include "ScrollState.h"
 #include "widgets/TerminalHeaderBar.h"
 
+#include "TerminalBell.h"
+
 class QDrag;
 class QDragEnterEvent;
 class QDropEvent;
@@ -133,6 +137,7 @@ public:
 
     void setSessionController(SessionController *controller);
     SessionController *sessionController();
+    Session::Ptr session() const;
 
     /**
      * Sets the shape of the keyboard cursor.  This is the cursor drawn
@@ -205,22 +210,6 @@ public:
      */
     void setWordCharacters(const QString &wc);
 
-    /**
-     * Sets the type of effect used to alert the user when a 'bell' occurs in the
-     * terminal session.
-     *
-     * The terminal session can trigger the bell effect by calling bell() with
-     * the alert message.
-     */
-    void setBellMode(int mode);
-    /**
-     * Returns the type of effect used to alert the user when a 'bell' occurs in
-     * the terminal session.
-     *
-     * See setBellMode()
-     */
-    int bellMode() const;
-
     TerminalHeaderBar *headerBar() const
     {
         return _headerBar;
@@ -297,7 +286,7 @@ public:
 
     TerminalFont *terminalFont() const
     {
-        return _terminalFont;
+        return _terminalFont.get();
     }
 
     bool cursorBlinking() const
@@ -336,6 +325,9 @@ public:
     // returns the position of the cursor in columns and lines
     QPoint cursorPosition() const;
 
+    // returns 0 - not selecting, 1 - pending selection (button pressed but no movement yet), 2 - selecting
+    int selectionState() const;
+
 public Q_SLOTS:
     /**
      * Scrolls current ScreenWindow
@@ -349,11 +341,6 @@ public Q_SLOTS:
      * terminal screen ( see setScreenWindow() ) and redraw the display.
      */
     void updateImage();
-    /**
-     * Causes the terminal display to fetch the latest line status flags from the
-     * associated terminal screen ( see setScreenWindow() ).
-     */
-    void updateLineProperties();
 
     void setAutoCopySelectedText(bool enabled);
 
@@ -506,7 +493,7 @@ Q_SIGNALS:
     
     void drawBackground(QPainter &painter, const QRect &rect, const QColor &backgroundColor, bool useOpacitySetting);
     void drawCharacters(QPainter &painter, const QRect &rect, const QString &text,
-                            const Character *style, const QColor &characterColor);
+                            const Character *style, const QColor &characterColor, const LineProperty lineProperty);
     void drawInputMethodPreeditString(QPainter &painter, const QRect &rect, TerminalDisplay::InputMethodData &inputMethodData, Character *image);
 
 protected:
@@ -666,7 +653,7 @@ private:
     Enum::MiddleClickPasteModeEnum _middleClickPasteMode;
 
     QString _wordCharacters;
-    int _bellMode;
+    TerminalBell _bell;
 
     bool _allowBlinkingText;  // allow text to blink
     bool _allowBlinkingCursor;  // allow cursor to blink
@@ -749,9 +736,9 @@ private:
     TerminalPainter *_terminalPainter;
     TerminalScrollBar *_scrollBar;
     TerminalColor *_terminalColor;
-    TerminalFont *_terminalFont;
+    std::unique_ptr<TerminalFont> _terminalFont;
 
-    KonsolePrintManager *_printManager;
+    std::unique_ptr<KonsolePrintManager> _printManager;
 };
 
 }
